#!/usr/bin/env bash

set -e

DURATION=15
SCALE=50
DATADIR=/mnt/data/data-scaling
TS=$(date +%s)
CLIENTS=$(seq 1 192)
LABEL=$1

mkdir -p stat/$TS logs/$TS

dropdb --if-exists bench > logs/$TS/init.log 2>&1
createdb bench >> logs/$TS/init.log 2>&1

pgbench -i -s $SCALE bench >> logs/$TS/init.log 2>&1

psql bench -c "vacuum analyze" >> logs/$TS/init.log 2>&1
psql bench -c "checkpoint" >> logs/$TS/init.log 2>&1

pg_ctl -D $DATADIR -l logs/pg-$TS.log restart >> logs/$TS/init.log 2>&1

# warmup after restart
pgbench -S -M prepared -c 96 -j 96 -T 60 bench >> logs/$TS/init.log 2>&1

for p in none colocated random; do

	for c in $CLIENTS; do

		if [ "$c" == "0" ]; then c=1; fi

		# run the pgbench in the background, collect perf stats
		if [ "$p" == "none" ]; then
			pgbench -n -S -M prepared -c $c -j $c -T $DURATION bench >> logs/$TS/pgbench.$p.$c.log 2>&1
		else
			pgbench -n -S -M prepared -c $c -j $c -T $DURATION --pin-cpus $p bench >> logs/$TS/pgbench.$p.$c.log 2>&1
		fi

		tps=$(grep 'tps = ' logs/$TS/pgbench.$p.$c.log | awk '{print $3}')

		echo $p $c $tps >> perf-stat-$TS-$LABEL.csv

	done;

done;
